@@ -2,6 +2,7 @@
 """
 Example of an input box dialog.
 """
+
 from prompt_toolkit.shortcuts import input_dialog
 
 
@@ -10,7 +11,7 @@ def main():
         title="Input dialog example", text="Please type your name:"
     ).run()
 
-    print("Result = {}".format(result))
+    print(f"Result = {result}")
 
 
 if __name__ == "__main__":
